# Core Library modules
from pathlib import Path

# Third party modules
import pytest

# First party modules
from pynball import pynball


def feedback(message, _):
    """A utility method to generate nicely formatted messages"""
    print(f"{message}")


@pytest.mark.parametrize(
    "wh, ph, out, err, return_value",
    [
        (Path("C:\\"), Path("C:\\"), "", "", 0),
        (
            Path(""),
            Path("C:\\"),
            "WARNING: Virtualenv-wrapper is not configured.\n",
            "",
            1,
        ),
        (
            Path("C:\\"),
            Path(""),
            "WARNING: Virtualenv-wrapper is not configured.\n",
            "",
            1,
        ),
        (Path(""), Path(""), "WARNING: Virtualenv-wrapper is not configured.\n", "", 1),
    ],
)
def test_check_virtual_env(capsys, wh, ph, out, err, return_value):
    # pb._feedback = feedback
    pynball._WORKON_HOME = wh
    pynball._PROJECT_HOME = ph
    x = pynball._check_virtual_env()
    output, error = capsys.readouterr()
    assert output == out
    assert error == err
    assert x == return_value



# Core Library modules
from pathlib import Path, PurePath, WindowsPath

# Third party modules
import pytest
from click.testing import CliRunner

# First party modules
from pynball import pynball


@pytest.mark.parametrize(
    "message, message_type, result",
    [
        ("this is a null message", "null", "None"),
        ("this is a nominal message", "nominal", "None"),
        ("this is a warning message", "warning", "None"),
        ("this is an error message", "error", "None"),
        ("this is an error message", "wrong", "None"),
    ],
)
def test_feedback(message, message_type, result):
    """Pytest test to assert mark parametrize pytest feature."""
    assert result == str(pynball._feedback(message, message_type))



# Core Library modules
from pathlib import Path

# Third party modules
import pytest

# First party modules
from pynball import pynball


@pytest.mark.parametrize(
    "ph, out, err, return_value",
    [
        (Path("C:\\"), "", "", 0),
        (Path(""), "WARNING: Pyenv is not configured.\n", "", 1),
    ],
)
def test_check_pyenv(capsys, ph, out, err, return_value):
    pynball._PYENV_HOME = ph
    x = pynball._check_pyenv()
    output, error = capsys.readouterr()
    assert output == out
    assert error == err
    assert x == return_value



# Core Library modules
import re
import sys

# First party modules
from pynball import pynball


def test_execute():
    pattern = r"\d+.\d+.\d+"
    py_ver_script = "{0.major}.{0.minor}.{0.micro}".format(sys.version_info)
    py_ver_cli = pynball._execute("python", "--version")
    assert re.findall(pattern, py_ver_script) == re.findall(pattern, py_ver_cli)
